@@ -1,10 +1,9 @@
-#' @title Function \code{build_times}
-#' @description List all the build times.
-#' This does not include the amount of time
+#' @title List the time it took to build each target/import.
+#' @description Listed times do not include the amount of time
 #' spent loading and saving objects!
 #' @seealso \code{\link{built}}
 #' @export
-#' @return data.frame of times from \code{\link{system.time}}
+#' @return A data frame of times, each from \code{\link{system.time}()}.
 #' @param targets_only logical, whether to only return the
 #' build times of the targets (exclude the imports).
 #' @param path Root directory of the drake project,
@@ -17,11 +16,15 @@
 #' @param cache optional drake cache. If supplied,
 #' the \code{path} and \code{search} arguments are ignored.
 #' @param verbose whether to print console messages
+#' @param jobs number of parallel jobs/workers for light parallelism.
 #' @examples
 #' \dontrun{
-#' load_basic_example()
-#' make(my_plan)
-#' build_times()
+#' test_with_dir("Quarantine side effects.", {
+#' # Show the build times for the basic example.
+#' load_basic_example() # Get the code with drake_example("basic").
+#' make(my_plan) # Build all the targets.
+#' build_times() # Show how long it took to build each target.
+#' })
 #' }
 build_times <- function(
   path = getwd(),
@@ -29,17 +32,19 @@ build_times <- function(
   digits = 3,
   cache = get_cache(path = path, search = search, verbose = verbose),
   targets_only = FALSE,
-  verbose = TRUE
+  verbose = TRUE,
+  jobs = 1
 ){
   if (is.null(cache)){
     return(empty_times())
   }
-  out <- lapply(
-    cache$list(namespace = "build_times"),
-    fetch_runtime,
+  out <- lightly_parallelize(
+    X = cache$list(namespace = "meta"),
+    FUN = fetch_runtime,
+    jobs = 1,
     cache = cache
   ) %>%
-    Filter(f = is.data.frame) %>%
+    parallel_filter(f = is.data.frame, jobs = jobs) %>%
     do.call(what = rbind) %>%
     rbind(empty_times()) %>%
     round_times(digits = digits) %>%
@@ -51,9 +56,17 @@ build_times <- function(
   }
   out
 }
-  
+
 fetch_runtime <- function(key, cache){
-  x <- cache$get(key = key, namespace = "build_times")
+  x <- get_from_subspace(
+    key = key,
+    subspace = "build_times",
+    namespace = "meta",
+    cache = cache
+  )
+  if (is_bad_time(x)){
+    return(empty_times())
+  }
   if (class(x) == "proc_time"){
     x <- runtime_entry(runtime = x, target = key, imported = NA)
   }
@@ -108,3 +121,17 @@ to_build_duration <- function(x){
 }
 
 time_columns <- c("elapsed", "user", "system")
+
+append_times_to_meta <- function(target, start, meta, config){
+  if (is_bad_time(start)){
+    return(meta)
+  }
+  build_times <- (proc.time() - start) %>%
+    runtime_entry(target = target, imported = meta$imported)
+  meta$build_times <- build_times
+  meta
+}
+
+is_bad_time <- function(x){
+  !length(x) || is.na(x[1])
+}
