@@ -1,14 +1,15 @@
-#' @title Function knitr_deps
+#' @title Find the drake dependencies of a dynamic knitr report target.
 #' @export
-#' @seealso \code{\link{knitr_deps}},
-#' \code{\link{deps}},
+#' @seealso \code{\link{deps}},
 #' \code{\link{make}}, \code{\link{load_basic_example}}
-#' @description Find the dependencies of a dynamic report. To
-#' enable drake to watch for these dependencies, your workplan
-#' plan command to compile this report must make direct use of
-#' \code{knitr::knit()}.
-#' That is, it must look something like \code{knit('your_report.Rmd')}
-#' in your workflow plan data frame.
+#' @description To enable drake to watch for the dependencies
+#' of a knitr report, the command in your workflow plan data frame
+#' must call \code{knitr::knit()} directly.
+#' In other words,
+#' the command must look something like
+#' \code{knit('your_report.Rmd')} or
+#' \code{knit('your_report.Rmd', quiet = TRUE)}.
+#' @return A character vector of the names of dependencies.
 #' @details Drake looks for dependencies in the document by
 #' analyzing evaluated code chunks for other targets/imports
 #' mentioned in \code{\link{loadd}()} and \code{\link{readd}()}.
@@ -16,26 +17,40 @@
 #' source text of the document.
 #' @examples
 #' \dontrun{
-#' load_basic_example()
-#' knitr_deps("'report.Rmd'") # Files must be single-quoted
+#' test_with_dir("Quarantine side effects.", {
+#' load_basic_example() # Get the code with drake_example("basic").
+#' knitr_deps("'report.Rmd'") # Files must be single-quoted.
+#' # Find the dependencies of the compiled output target, 'report.md'.
 #' knitr_deps("report.Rmd")
-#' make(my_plan)
-#' knitr_deps("'report.md'") # Work on the Rmd source, not the output.
+#' make(my_plan) # Run the project.
+#' # Work only on the Rmd source, not the output.
+#' try(knitr_deps("'report.md'"), silent = FALSE) # error
+#' })
 #' }
 knitr_deps <- function(target){
   if (!length(target)){
     return(character(0))
   }
-  file <- unquote(target)
+  file <- drake_unquote(target)
   if (!file.exists(file)){
     warning(
-      "dynamic report '", file,
+      "knitr/rmarkdown report '", file,
       "' does not exist and cannot be inspected for dependencies.",
       call. = FALSE
     )
     return(character(0))
   }
-  fragments <- get_tangled_frags(file)
+  fragments <- tryCatch({
+      get_tangled_frags(file)
+    },
+    error = function(e){
+      warning(
+        "Could not parse file '", file,
+        "'. Drake dependencies could not be extracted from code chunks."
+      )
+      character(0)
+    }
+  )
   sort(find_knitr_targets(fragments))
 }
 
@@ -53,7 +68,10 @@ find_knitr_doc <- function(expr, result = character(0)){
   if (is.function(expr)){
     result <- find_knitr_doc(body(expr), result = result)
   } else if (is.call(expr) & length(expr) > 1){
-    if (is_function_call(expr, package = "knitr", what = "knit")){
+    does_knitting <-
+      is_function_call(expr, package = "knitr", what = "knit") ||
+      is_function_call(expr, package = "rmarkdown", what = "render")
+    if (does_knitting){
       result <- doc_of_function_call(expr)
     } else {
       result <- lapply(as.list(expr), find_knitr_doc,
@@ -79,7 +97,11 @@ doc_of_function_call <- function(expr){
   if (!is.null(args$input)){
     as.character(args$input)
   } else {
-    input_index <- min(which(!nchar(names(args))))
+    unnamed <- which(!nchar(names(args)))
+    if (!length(unnamed)){
+      return(character(0))
+    }
+    input_index <- min(unnamed)
     as.character(args[[input_index]])
   }
 }
@@ -134,12 +156,12 @@ analyze_readd <- function(expr){
 
 is_function_call <- function(
   expr,
-  package = c("drake", "knitr"),
-  what = c("knit", "loadd", "readd")
+  package = c("drake", "knitr", "rmarkdown"),
+  what = c("loadd", "readd", "knit", "render")
 ){
   package <- match.arg(package)
   what <- match.arg(what)
-  eply::unquote(deparse(expr[[1]])) %in%
+  drake::drake_unquote(deparse(expr[[1]])) %in%
     paste0(c("", paste0(package, c("::", ":::"))), what)
 }
 
@@ -150,9 +172,7 @@ found_loadd_readd <- function(x){
 get_specific_arg <- function(args, name){
   tryCatch(
     eval(args[[name]]),
-    error = function(e){
-      character(0)
-    }
+    error = error_character0
   )
 }
 
