@@ -1,14 +1,18 @@
 run_mclapply <- function(config){
-  do_prework(config = config, verbose_packages = TRUE)
   run_parallel(config = config, worker = worker_mclapply)
 }
 
-worker_mclapply <- function(targets, hash_list, config){
+worker_mclapply <- function(targets, meta_list, config){
   prune_envir(targets = targets, config = config)
   jobs <- safe_jobs(config$jobs)
-  values <- mclapply(targets, build, hash_list = hash_list,
-    config = config, mc.cores = jobs)
-  assign_to_envir(target = targets, value = values, config = config)
+  values <- mclapply(
+    X = targets,
+    FUN = drake_build_worker,
+    meta_list = meta_list,
+    config = config,
+    mc.cores = jobs
+  )
+  assign_to_envir(targets = targets, values = values, config = config)
 }
 
 warn_mclapply_windows <- function(
