@@ -1,30 +1,95 @@
 drake_context("cache")
 
+test_with_dir("dependency profile", {
+  config <- make(drake_plan(a = 1))
+  expect_error(dependency_profile(
+    target = "notfound", config = config))
+  expect_true(is.list(dependency_profile(
+    target = "a", config = config)))
+})
+
+test_with_dir("Cache namespaces", {
+  x <- cache_namespaces()
+  y <- target_namespaces()
+  z <- cleaned_namespaces()
+  expect_true(all(y %in% x))
+  expect_true(all(z %in% y))
+  expect_false(all(x %in% y))
+  expect_false(all(y %in% z))
+})
+
 test_with_dir("clean() works if there is no cache already", {
   clean(list = "no_cache")
   expect_false(file.exists(default_cache_path()))
 })
 
-test_with_dir("corrupt cache", {
-  x <- workplan(a = 1)
-  make(x, verbose = FALSE)
+test_with_dir("bad/corrupt caches, no progress", {
+  expect_null(drake_fetch_rds("sldkfjlke"))
+  expect_warning(new_cache(type = "nope"))
+  x <- drake_plan(a = 1)
+  make(x, verbose = FALSE, session_info = FALSE, log_progress = FALSE)
+  expect_equal(get_cache()$list(namespace = "progress"), character(0))
+  clean()
+  make(x, verbose = FALSE, session_info = FALSE, log_progress = TRUE)
+  expect_equal(get_cache()$list(namespace = "progress"), "a")
   path <- file.path(default_cache_path(), "config", "hash_algorithm")
   expect_true(file.exists(path))
   unlink(path)
   expect_false(file.exists(path))
-  expect_warning(expect_error(make(x, verbose = FALSE)))
+  expect_warning(expect_error(
+    make(x, verbose = FALSE, session_info = FALSE)))
 })
 
-test_with_dir("try to find a non-existent project", {
+test_with_dir("non-existent caches", {
+  expect_equal(0, nrow(drake_cache_log()))
+  check_storr_short_hash(NULL, "BLAH")
   expect_equal(find_cache(), NULL)
   expect_equal(find_project(), NULL)
   expect_error(loadd(list = "nothing", search = FALSE))
-  expect_error(tmp <- read_config(search = FALSE))
-  expect_error(tmp <- session(search = FALSE))
+  expect_error(tmp <- read_drake_config(search = FALSE))
+  expect_error(tmp <- read_drake_plan(search = FALSE))
+  expect_error(tmp <- read_drake_graph(search = FALSE))
+  expect_error(tmp <- read_drake_meta(search = FALSE))
+  expect_error(tmp <- drake_session(search = FALSE))
+  dummy <- new_cache()
+  expect_silent(read_drake_graph(cache = dummy))
+})
+
+test_with_dir("try to rescue non-existent stuff", {
+  expect_null(rescue_cache())
+  cache <- storr_rds("dummy_cache")
+  expect_silent(rescue_del(key = "no_key", cache = cache, namespace = "none"))
+})
+
+test_with_dir("subspaces", {
+  lst <- list_subspace(
+    subspace = "y", namespace = "x", cache = NULL, jobs = 1)
+  expect_equal(lst, character(0))
+  x <- storr::storr_rds("test")
+  lst <- list_subspace(
+    subspace = "y", namespace = "x", cache = x, jobs = 1)
+  expect_equal(lst, character(0))
+  set_in_subspace(
+    key = "a",
+    value = 1,
+    namespace = "x",
+    subspace = "y",
+    cache = x
+  )
+  set_in_subspace(
+    key = "b",
+    value = 2,
+    namespace = "x",
+    subspace = "y",
+    cache = x
+  )
+  lst <- list_subspace(
+    subspace = "y", namespace = "x", cache = x, jobs = 1)
+  expect_equal(sort(lst), c("a", "b"))
 })
 
 test_with_dir("cache functions work", {
-  # May have been loaded in a globalenv() testing scenario
+  # May have been loaded in a globalenv() testing scenario # nolint
   remove_these <- intersect(ls(envir = globalenv()), c("h", "j"))
   rm(list = remove_these, envir = globalenv())
 
@@ -34,7 +99,8 @@ test_with_dir("cache functions work", {
   if (!file.exists(scratch)){
     dir.create(scratch) # Will move up a level later.
   }
-  setwd(scratch)
+  # Suppress goodpractice::gp(): legitimate need for setwd(). # nolint
+  eval(parse(text = "setwd(scratch)"))
   owd <- getwd()
   expect_equal(character(0), cached(search = FALSE), imported(search = FALSE),
     built(search = FALSE))
@@ -50,8 +116,27 @@ test_with_dir("cache functions work", {
     envir <- environment()
   }
 
+  config$session_info <- TRUE
   testrun(config)
 
+  # drake_cache_log() # nolint
+  all_hashes <- drake_cache_log()
+  some_hashes <- drake_cache_log(targets_only = TRUE)
+  expect_equal(ncol(all_hashes), ncol(some_hashes))
+  n_a <- nrow(all_hashes)
+  n_s <- nrow(some_hashes)
+  expect_true(n_a > n_s && n_s > 0)
+  expect_false(file.exists("log.txt"))
+  drake_cache_log_file(file = "log.txt")
+  expect_true(file.exists("log.txt"))
+
+  # drake_gc() should not remove any important targets/imports.
+  x <- cached()
+  expect_true(length(x) > 0)
+  drake_gc()
+  y <- cached()
+  expect_equal(sort(x), sort(y))
+
   # targets
   all <- sort(c("'input.rds'",
     "'intermediatefile.rds'", "a",
@@ -65,7 +150,7 @@ test_with_dir("cache functions work", {
   # build_times
   x <- config$cache
   bt <- build_times(search = FALSE, targets_only = FALSE)
-  expect_equal(sort(x$list(namespace = "build_times")), sort(cached()))
+  expect_equal(sort(x$list(namespace = "meta")), sort(cached()))
   expect_equal(sort(bt$item), all)
   expect_length(bt, 5) # 5 columns
   n1 <- nrow(bt)
@@ -73,10 +158,9 @@ test_with_dir("cache functions work", {
   expect_true(n1 > n2 & n2 > 0)
 
   # find stuff in current directory session, progress
-  expect_true(is.list(session(search = FALSE)))
+  expect_true(is.list(drake_session(search = FALSE)))
   expect_true(all(progress(search = FALSE) == "finished"))
   expect_equal(in_progress(search = FALSE), character(0))
-  expect_warning(tmp <- status(search = FALSE))
   expect_warning(tmp <- progress(imported_files_only = TRUE))
   expect_equal(sort(names(progress(search = FALSE))), all)
   expect_equal(
@@ -87,14 +171,21 @@ test_with_dir("cache functions work", {
       final = "finished"))
 
   # config
-  newconfig <- read_config(search = FALSE)
+  newconfig <- read_drake_config(search = FALSE)
   expect_equal(newconfig$short_hash_algo, default_short_hash_algo())
   expect_equal(newconfig$long_hash_algo, default_long_hash_algo())
   expect_true(is.list(newconfig) & length(newconfig) > 1)
-  expect_equal(read_plan(search = FALSE), config$plan)
-  expect_equal(class(read_graph(search = FALSE)), "igraph")
-
-  # imported , built, cached, diagnose
+  expect_equal(read_drake_plan(search = FALSE), config$plan)
+  expect_true(inherits(read_drake_graph(search = FALSE), "igraph"))
+  expect_true(is.list(
+    tmp <- read_drake_meta(targets = "final", search = FALSE)))
+  expect_true(is.list(
+    tmp <- read_drake_meta(
+      targets = c("final", "yourinput"), search = FALSE)))
+  expect_equal(sort(names(tmp)), sort(c("final", "yourinput")))
+  expect_true(is.list(tmp <- read_drake_meta(search = FALSE)))
+  expect_true(length(tmp) > 1)
+  # imported , built, cached, diagnose, rescue
   expect_equal(diagnose(search = FALSE), character(0))
   expect_equal(imported(files_only = FALSE, search = FALSE),
     imports)
@@ -113,6 +204,13 @@ test_with_dir("cache functions work", {
   expect_equal(sort(cached(i, bla, list = c("final", "run"),
     search = FALSE)), sort(c(i = TRUE, bla = FALSE, final = TRUE,
     run = FALSE)))
+  expect_true(
+    inherits(rescue_cache(search = FALSE, targets = "final"), "storr"))
+  expect_true(inherits(
+    rescue_cache(search = FALSE, garbage_collection = FALSE), "storr"))
+  expect_true(inherits(
+    rescue_cache(search = FALSE, garbage_collection = TRUE), "storr"))
+  expect_equal(sort(cached(search = FALSE)), sort(all), twopiece)
 
   # find your project
   expect_equal(find_project(), getwd())
@@ -142,15 +240,15 @@ test_with_dir("cache functions work", {
     dir.create("searchfrom")
     dir.create(file.path("searchfrom", "here"))
   }
-  setwd("..")
+  # Suppress goodpractice::gp(): legitimate need for setwd(). # nolint
+  eval(parse(text = "setwd('..')"))
   expect_equal(getwd(), first_wd)
   s <- normalizePath(file.path(scratch, "searchfrom", "here"))
 
   # progress, session
-  expect_true(is.list(session(search = TRUE, path = s)))
+  expect_true(is.list(drake_session(search = TRUE, path = s)))
   expect_equal(sort(names(progress(search = TRUE, path = s))),
     sort(all))
-  expect_warning(status(search = TRUE, path = s))
   expect_equal(sort(names(progress(no_imported_objects = TRUE,
     search = TRUE, path = s))), sort(c("'input.rds'", builds)))
   expect_equal(sort(progress(search = TRUE, path = s, bla, f,
@@ -174,6 +272,8 @@ test_with_dir("cache functions work", {
   expect_equal(sort(cached(no_imported_objects = TRUE, path = s,
     search = T)), sort(c("'input.rds'", builds)))
   expect_true(all(cached(list = all, path = s, search = TRUE)))
+  expect_true(inherits(rescue_cache(path = s, search = TRUE), "storr"))
+  expect_true(all(cached(list = all, path = s, search = TRUE)))
 
   # find your project
   expect_equal(find_project(path = s), file.path(scratch))
@@ -181,10 +281,10 @@ test_with_dir("cache functions work", {
     file.path(scratch, cache_dir))
 
   # config
-  newconfig <- read_config(search = TRUE, path = s)
+  newconfig <- read_drake_config(search = TRUE, path = s)
   expect_true(is.list(newconfig) & length(newconfig) > 1)
-  expect_equal(read_plan(search = TRUE, path = s), config$plan)
-  expect_equal(class(read_graph(search = TRUE, path = s)),
+  expect_equal(read_drake_plan(search = TRUE, path = s), config$plan)
+  expect_equal(class(read_drake_graph(search = TRUE, path = s)),
     "igraph")
 
   # load and read stuff
@@ -196,30 +296,51 @@ test_with_dir("cache functions work", {
   rm(h, i, j, c, envir = envir)
   expect_error(h(1))
 
+  # load dependencies
+  e <- new.env()
+  deps <- c("nextone", "yourinput")
+  expect_false(any(deps %in% ls(envir = e)))
+  loadd(combined, deps = TRUE, path = s, search = TRUE, envir = e)
+  expect_true(all(deps %in% ls(envir = e)))
+
   # Read the graph
   pdf(NULL)
   tmp <- dbug()
-  tmp <- read_graph(search = TRUE, path = s)
+  tmp <- read_drake_graph(search = TRUE, path = s)
   tmp <- capture.output(dev.off())
   unlink("Rplots.pdf", force = TRUE)
 
-  setwd(scratch)
+  # Suppress goodpractice::gp(): legitimate need for setwd(). # nolint
+  eval(parse(text = "setwd(scratch)"))
   pdf(NULL)
-  tmp <- read_graph(search = FALSE)
+  tmp <- read_drake_graph(search = FALSE)
   tmp <- capture.output(dev.off())
   unlink("Rplots.pdf", force = TRUE)
   pdf(NULL)
   null_graph()
   tmp <- capture.output(dev.off())
   unlink("Rplots.pdf", force = TRUE)
-  setwd("..")
+  # Suppress goodpractice::gp(): legitimate need for setwd(). # nolint
+  eval(parse(text = "setwd('..')"))
 
   # clean using search = TRUE or FALSE
   expect_true(all(all %in% cached(path = s, search = T)))
-  clean(final, path = s, search = TRUE)
+  clean(final, path = s, search = TRUE, jobs = 2,
+    garbage_collection = TRUE)
   expect_true(all(setdiff(all, "final") %in% cached(path = s,
     search = T)))
-  clean(path = s, search = TRUE)
+  drake_gc(path = s, search = T)
+
+  # Test purging
+  prog <- progress(search = TRUE, path = s)
+  expect_true("final" %in% names(prog))
+  clean(final, path = s, search = TRUE, jobs = 2,
+    garbage_collection = TRUE, purge = TRUE)
+  prog <- progress(search = TRUE, path = s)
+  expect_false("final" %in% names(prog))
+
+  # More cleaning checks
+  clean(path = s, search = TRUE, garbage_collection = FALSE)
   expect_equal(cached(path = s, search = T), character(0))
   where <- file.path(scratch, cache_dir)
   expect_true(file.exists(where))
@@ -227,7 +348,9 @@ test_with_dir("cache functions work", {
   expect_true(file.exists(where))
   clean(path = s, search = TRUE, destroy = TRUE)
   expect_false(file.exists(where))
+  expect_silent(drake_gc()) # Cache does not exist
 
-  setwd(scratch)
+  # Suppress goodpractice::gp(): legitimate need for setwd(). # nolint
+  eval(parse(text = "setwd(scratch)"))
   unlink("searchfrom", recursive = TRUE, force = TRUE)
 })
