@@ -22,7 +22,7 @@ test_with_dir(
   expect_false(is_vectorized(f))
   expect_false(is_vectorized("char"))
   expect_equal(sort(deps(f)), sort(c("g", "saveRDS")))
-  my_plan <- workplan(
+  my_plan <- drake_plan(
     x = 1 + some_object,
     my_target = x + readRDS("tracked_input_file.rds"),
     return_value = f(x, y, g(z + w)))
@@ -31,15 +31,6 @@ test_with_dir(
     sort(c("'tracked_input_file.rds'", "readRDS", "x")))
   expect_equal(sort(deps(my_plan$command[3])), sort(c("f", "g", "w",
     "x", "y", "z")))
-
-  load_basic_example()
-  expect_equal(sort(deps("'report.Rmd'")), sort(c(
-    "coef_regression2_small", "large", "small"
-  )))
-  f <- function(x){
-    knit(x)
-  }
-  expect_equal(deps(f), "knit")
 })
 
 test_with_dir("tracked() works", {
@@ -57,12 +48,49 @@ test_with_dir("tracked() works", {
   expect_equal(x, y)
 })
 
-test_with_dir("missing files via check()", {
+test_with_dir("missing files via check_plan()", {
   config <- dbug()
-  expect_output(check(config$plan, envir = config$envir))
+  expect_message(check_plan(config$plan, envir = config$envir))
   expect_silent(tmp <- missing_input_files(config))
   unlink("input.rds", force = TRUE)
   expect_warning(
-    tmp <- capture.output(check(config$plan, envir = config$envir)))
+    tmp <- capture.output(check_plan(config$plan, envir = config$envir)))
   expect_warning(tmp <- missing_input_files(config))
 })
+
+test_with_dir("Vectorized nested functions work", {
+  e <- new.env(parent = globalenv())
+  eval(parse(text = "f <- Vectorize(function(x) g(x), \"x\")"),
+       envir = e)
+  eval(parse(text = "g <- function(x) x + y"), envir = e)
+  e$y <- 7
+  config <- dbug()
+  config$envir <- e
+  config$plan <- drake_plan(a = f(1:10))
+  config$targets <- "a"
+  expect_equal(deps(e$f), "g")
+  expect_equal(deps(e$g), "y")
+
+  config <- testrun(config)
+  if ("a" %in% ls(config$envir)){
+    rm(a, envir = config$envir)
+  }
+  expect_equal(readd(a), 8:17)
+  k <- readd(f)
+  expect_equal(k(2:5), 9:12)
+  expect_equal(character(0), outdated(config))
+  config$envir$y <- 8
+  expect_equal("a", outdated(config))
+
+  # Target "a" should react.
+  config <- testrun(config)
+  expect_equal(character(0), outdated(config))
+  expect_equal(readd(a), 9:18)
+
+  # Change a vectorized function and see target "a" react.
+  eval(parse(text = "f <- Vectorize(function(x){g(x) + 3}, \"x\")"),
+       envir = e)
+  config <- testrun(config)
+  expect_equal(justbuilt(config), "a")
+  expect_equal(readd(a), 12:21)
+})
