@@ -9,7 +9,7 @@ test_with_dir("scratch build with custom filesystem cache.", {
     short_hash_algo = "murmur32",
     long_hash_algo = "sha512"
   )
-  expect_error(session(cache = cache))
+  expect_error(drake_session(cache = cache))
   expect_true(length(progress(cache = cache)) == 0)
   expect_equal(config$cache$list(), character(0))
 
@@ -18,8 +18,8 @@ test_with_dir("scratch build with custom filesystem cache.", {
   expect_true(is.numeric(readd(final, cache = cache)))
   expect_true(length(config$cache$list()) > 2)
   expect_false(any(c("f", "final") %in% ls()))
-  expect_true(is.list(session(cache = cache)))
-  expect_true(all(session(cache = cache)$target %in% config$plan$target))
+  expect_true(
+    all(read_drake_plan(cache = cache)$target %in% config$plan$target))
 
   cache <- this_cache(path = path)
   expect_equal(short_hash(cache), "murmur32")
@@ -47,36 +47,36 @@ test_with_dir("scratch build with custom filesystem cache.", {
     cache = cache)
   expect_false(file.exists("intermediatefile.rds"))
   expect_true(file.exists("input.rds"))
-  expect_equal(config$cache$list(), setdiff(all, c("b", "c",
-    "'intermediatefile.rds'", "nextone")))
+  expect_equal(config$cache$list(),
+    setdiff(all, c("b", "c", "'intermediatefile.rds'", "nextone")))
 
   # clean does not remove imported files
   expect_true(file.exists("input.rds"))
-  expect_true("'input.rds'" %in% config$cache$list())
+  expect_true("'input.rds'" %in%
+    config$cache$list())
   clean("'input.rds'", cache = cache)
   expect_true(file.exists("input.rds"))
-  expect_false("'input.rds'" %in% config$cache$list())
+  expect_false("'input.rds'" %in%
+    config$cache$list())
 
   # clean removes imported functions and cleans up 'functions'
   # namespace
   expect_true(cached(f, cache = cache))
-  for (n in c("objects", "depends", "functions")) {
+  for (n in c(cache$default_namespace, "kernels")) {
     expect_true("f" %in% config$cache$list(namespace = n))
   }
   clean(f, cache = cache)
-  for (n in c("objects", "depends", "functions")) {
+  for (n in c(cache$default_namespace, "kernels")) {
     expect_false("f" %in% config$cache$list(namespace = n))
   }
 
   clean(destroy = FALSE, cache = cache)
   expect_equal(config$cache$list(), character(0))
-  expect_equal(config$cache$list("depends"), character(0))
-  expect_equal(config$cache$list("functions"), character(0))
+  expect_equal(config$cache$list("kernels"), character(0))
   expect_false(file.exists("intermediatefile.rds"))
   expect_true(file.exists("input.rds"))
   expect_false(file.exists(default_cache_path()))
   expect_true(file.exists(path))
-  expect_equal(config$cache$list("filemtime"), character(0))
 
   clean(destroy = TRUE, cache = cache)
   expect_false(file.exists(path))
