@@ -1,5 +1,4 @@
-cat(get_testing_scenario_name(), ": ", sep = "")
-context("intermediate file")
+drake_context("intermediate file")
 
 test_with_dir("responses to intermediate file", {
   config <- dbug()
